pub trait DeserializeCopy: Deserializeable + Sized {
// Required method
fn deserialize_copy<R: DataInput + ?Sized>(input: &mut R) -> Result<Self>;
}Expand description
A trait for types which can be deserialized and produce a new instance It’s intended that this impl should be more efficient then creating a new instance, then reading into it
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".